@@ -90,8 +90,8 @@ file-like objects:
 
 __ver_major__ = 0
 __ver_minor__ = 3
-__ver_patch__ = 5
-__ver_sub__ = "p1"
+__ver_patch__ = 6
+__ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 
 
@@ -252,13 +252,12 @@ class FileLikeBase(object):
 
         The file may not be accessed further once it is closed.
         """
-        if not self.closed:
+        if not getattr(self,"closed",False):
             self.flush()
             self.closed = True
 
     def __del__(self):
-        if not getattr(self,"closed",True):
-            self.close()
+        self.close()
 
     def __enter__(self):
         return self
